---
gitea: none
include_toc: true
---
![Build Status](https://drone.mcos.nc/api/badges/laboro/laboro_template/status.svg) ![License](https://img.shields.io/static/v1?label=license&color=orange&message=MIT) ![Language](https://img.shields.io/static/v1?label=language&color=informational&message=Python)

# laboro_template

Laboro templating module

This module is intended to be used by the [**Laboro** NO-Code / Low-Code workflow manager](https://codeberg.org/laboro/laboro).
